=== modified file 'CHANGES'
--- CHANGES	2006-06-22 16:37:15 +0000
+++ CHANGES	2007-03-21 11:53:52 +0000
@@ -1,3 +1,18 @@
+1.82   2007-02-21 by Alexandr Ciornii (alexchorny AT gmail.com)
+  - Slightly faster test skip
+  - 99semaphore.t and 99flex.t check for cygserver on Cygwin
+  - 99flex.t skips less tests in some cases
+  - 99flex.t checks for Digest::MD5, MIME::Base64
+  - Warning in Apache::Session::Lock::Semaphore about cygserver
+  - Makefile.PL requires File::Temp
+  - changed order of use/chdir in tests (RT#16539, from Andrew Benham)
+
+1.81_01    2007-02-12 by Alexandr Ciornii
+  - My patch for Win32 and Cygwin (RT#18795)
+  - More information in Makefile.PL
+  - 99flex.t checks for Storable (RT#101)
+  - 99semaphore.t does not die if IPC:: modules are not present
+
 1.81   2006-05-23
 
   - Don't unconditionally try to require packages in Apache::Session::Flex
@@ -15,7 +30,7 @@
 
 ---
 
-Changes in 1.6:
+Changes in 1.6 (2004-02-24):
 
 Fixed file age test for clean().  The previous test was never true.
 
@@ -28,7 +43,7 @@
 Informix support from Mike Langen <mike.langen@tamedia.ch>.  Unfortunately no
 tests were included.
 
-Changes in 1.54:
+Changes in 1.54 (2001-10-11):
 
 Added mod_uniqueid and mod_usertrack generators from 
 Tatsuhiko Miyagawa <miyagawa@bulknews.net>
@@ -37,7 +52,7 @@
 
 Move to Digest::MD5 instead of MD5.
 
-Changes in 1.53:
+Changes in 1.53 (2000-09-01):
 
 ?
 

=== modified file 'INSTALL' (properties changed: +x to -x)
=== modified file 'META.yml'
--- META.yml	2006-06-22 16:37:15 +0000
+++ META.yml	2007-03-21 11:53:52 +0000
@@ -1,13 +1,17 @@
-# http://module-build.sourceforge.net/META-spec.html
-#XXXXXXX This is a prototype!!!  It will change in the future!!! XXXXX#
-name:         Apache-Session
-version:      1.81
-version_from: Session.pm
-installdirs:  site
-requires:
-    Test::Deep:                    0.082
-    Test::Exception:               0.15
-    Test::More:                    0.47
-
-distribution_type: module
-generated_by: ExtUtils::MakeMaker version 6.17
+--- #YAML:1.0
+name:                Apache-Session
+version:             1.82
+abstract:            A persistence framework for session data
+license:             perl
+generated_by:        ExtUtils::MakeMaker version 6.31
+distribution_type:   module
+requires:     
+    File::Temp:                    0
+    Test::Deep:                    0.082
+    Test::Exception:               0.15
+    Test::More:                    0.47
+meta-spec:
+    url:     http://module-build.sourceforge.net/META-spec-v1.2.html
+    version: 1.2
+author:
+    - Casey West <casey[at]geeknest.com>

=== modified file 'Makefile.PL'
--- Makefile.PL	2006-06-22 16:37:15 +0000
+++ Makefile.PL	2007-03-21 11:53:52 +0000
@@ -3,9 +3,14 @@
 WriteMakefile(
     NAME         => "Apache::Session",
     VERSION_FROM => "Session.pm",
+    ($ExtUtils::MakeMaker::VERSION ge '6.30_00'? 
+     ('LICENSE'		=> 'perl', ) : ()),
     PREREQ_PM    => {
                      'Test::More'      => '0.47',
                      'Test::Deep'      => '0.082',
                      'Test::Exception' => '0.15',
+                     'File::Temp'      => 0, #core from 5.6.1
                     },
+    AUTHOR          => 'Casey West <casey[at]geeknest.com>',
+    ABSTRACT        => 'A persistence framework for session data',
 );

=== modified file 'Session.pm'
--- Session.pm	2006-06-22 16:37:15 +0000
+++ Session.pm	2007-03-21 11:53:52 +0000
@@ -312,7 +312,7 @@
 use strict;
 use vars qw($VERSION);
 
-$VERSION = '1.81';
+$VERSION = '1.82';
 
 #State constants
 #

=== modified file 'Session/Lock/File.pm'
--- Session/Lock/File.pm	2004-10-08 17:18:42 +0000
+++ Session/Lock/File.pm	2007-03-21 11:53:52 +0000
@@ -15,7 +15,7 @@
 use Symbol;
 use vars qw($VERSION);
 
-$VERSION = '1.02';
+$VERSION = '1.03';
 
 $Apache::Session::Lock::File::LockDirectory = '/tmp';
 
@@ -26,10 +26,19 @@
 }
 
 sub acquire_read_lock  {
+    if ($^O eq 'MSWin32' or $^O eq 'cygwin') {
+        #Windows cannot escalate lock, so all locks will be exclusive
+        return &acquire_write_lock;
+    }
+    #Works for acquire_read_lock => acquire_write_lock => release_all_locks
+    #This hack does not support release_read_lock
+    #Changed by Alexandr Ciornii, 2006-06-21
+
     my $self    = shift;
     my $session = shift;
     
     return if $self->{read};
+    #does not support release_read_lock
 
     if (!$self->{opened}) {
         my $fh = Symbol::gensym();
@@ -70,6 +79,9 @@
 }
 
 sub release_read_lock  {
+    if ($^O eq 'MSWin32' or $^O eq 'cygwin') {
+        die "release_read_lock is not supported on Win32 or Cygwin";
+    }
     my $self    = shift;
     my $session = shift;
     
@@ -134,11 +146,16 @@
     foreach my $file (@files) {
         if ($file =~ /^Apache-Session.*\.lock$/) {
             if ($now - (stat($dir.'/'.$file))[8] >= $time) {
+              if ($^O eq 'MSWin32') {
+                #Windows cannot unlink opened file
+                unlink($dir.'/'.$file) || next;
+              } else {
                 open(FH, "+>$dir/".$file) || next;
                 flock(FH, LOCK_EX) || next;
                 unlink($dir.'/'.$file) || next;
                 flock(FH, LOCK_UN);
                 close(FH);
+              }
             }
         }
     }       
@@ -186,7 +203,7 @@
 =head1 NOTES
 
 This module does not unlink temporary files, because it interferes with proper
-locking.  THis can cause problems on certain systems (Linux) whose file systems
+locking.  This can cause problems on certain systems (Linux) whose file systems
 (ext2) do not perform well with lots of files in one directory.  To prevent this
 you should use a script to clean out old files from your lock directory.
 The meaning of old is left as a policy decision for the implementor, but a
@@ -197,6 +214,14 @@
  my $l = new Apache::Session::Lock::File;
  $l->clean('/var/lock/sessions', 3600) #remove files older than 1 hour
 
+=head2 Win32 and Cygwin
+
+Windows cannot escalate lock, so all locks will be exclusive.
+
+release_read_lock not supported - it is not used by Apache::Session.
+
+When deleting files, they are not locked (Win32 only).
+
 =head1 AUTHOR
 
 This module was written by Jeffrey William Baker <jwbaker@acm.org>.

=== modified file 'Session/Lock/Semaphore.pm'
--- Session/Lock/Semaphore.pm	2006-06-22 16:37:15 +0000
+++ Session/Lock/Semaphore.pm	2007-03-21 11:53:52 +0000
@@ -224,6 +224,13 @@
 one time and 16 sempahores the next, it won't work.  Use the system
 commands ipcs and ipcrm to inspect and remove unwanted semphore blocks.
 
+=head2 Cygwin
+
+IPC on Cygwin requires running cygserver. Without it, program will exit with
+"Bad System call" message. It cannot be intercepted with eval.
+
+Read /usr/share/doc/Cygwin/cygserver.README for more information.
+
 =head1 AUTHOR
 
 This module was written by Jeffrey William Baker <jwbaker@acm.org>.

=== modified file 'eg/example.perl' (properties changed: +x to -x)
=== modified file 't/99dbfile.t'
--- t/99dbfile.t	2006-06-22 16:37:15 +0000
+++ t/99dbfile.t	2007-03-21 11:53:52 +0000
@@ -53,4 +53,4 @@
 
 tied(%session)->delete;
 
-chdir( $origdir );
\ No newline at end of file
+chdir( $origdir );

=== modified file 't/99dbfilestore.t'
--- t/99dbfilestore.t	2006-06-22 16:37:15 +0000
+++ t/99dbfilestore.t	2007-03-21 11:53:52 +0000
@@ -11,6 +11,12 @@
 
 my $package = 'Apache::Session::Store::DB_File';
 
+plan tests => 13;
+
+use_ok $package;
+use_ok 'DB_File';
+can_ok $package, qw[new insert materialize remove];
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
@@ -28,12 +34,6 @@
                   },
 };
 
-plan tests => 13;
-
-use_ok $package;
-use_ok 'DB_File';
-can_ok $package, qw[new insert materialize remove];
-
 my $store = $package->new;
 isa_ok $store, $package;
 

=== modified file 't/99file.t'
--- t/99file.t	2006-06-22 16:37:15 +0000
+++ t/99file.t	2007-03-21 11:53:52 +0000
@@ -9,15 +9,15 @@
                require Fcntl;
               };
 
+plan tests => 9;
+
+my $package = 'Apache::Session::File';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 9;
-
-my $package = 'Apache::Session::File';
-use_ok $package;
-
 my %session;
 my %tie_params = (
     Directory     => '.',

=== modified file 't/99filelock.t'
--- t/99filelock.t	2006-06-22 16:37:15 +0000
+++ t/99filelock.t	2007-03-21 11:53:52 +0000
@@ -15,15 +15,15 @@
                require Fcntl;
               };
 
+plan tests => 4;
+
+my $package = 'Apache::Session::Lock::File';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 4;
-
-my $package = 'Apache::Session::Lock::File';
-use_ok $package;
-
 my $lock    = $package->new;
 my $session = {
     data => { _session_id   => 'foo' },

=== modified file 't/99filestore.t'
--- t/99filestore.t	2006-06-22 16:37:15 +0000
+++ t/99filestore.t	2007-03-21 11:53:52 +0000
@@ -9,15 +9,15 @@
                require Fcntl;
               };
 
+plan tests => 7;
+
+my $package = 'Apache::Session::Store::File';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 7;
-
-my $package = 'Apache::Session::Store::File';
-use_ok $package;
-
 my $session = {
     serialized => 12345,
     data => { _session_id => 'test1'},

=== modified file 't/99flex.t'
--- t/99flex.t	2006-06-22 16:37:15 +0000
+++ t/99flex.t	2007-03-21 11:53:52 +0000
@@ -4,23 +4,24 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
-plan skip_all => "Optional modules (Fcntl, DB_File, IPC::Semaphore, IPC::SysV) not installed: $@"
+#use Module::Mask;my $mask = new Module::Mask ('Storable');
+plan skip_all => "Optional modules (Fcntl, DB_File, Digest::MD5, Storable) not installed"
   unless eval {
                require Fcntl;
                require DB_File;
-               require IPC::Semaphore;
-               require IPC::SysV;
+               require Digest::MD5;
+               require Storable;
               };
 
+plan tests => 12;
+
+my $package = 'Apache::Session::Flex';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 12;
-
-my $package = 'Apache::Session::Flex';
-use_ok $package;
-
 {
     my $session = tie my %session, $package, undef, {
         Store     => 'File',
@@ -35,7 +36,16 @@
     is ref($session->{unserialize}), 'CODE', 'unserialize is CODE';
 }
 
-{
+SKIP: {
+    skip "Cygserver is not running",5 
+     if $^O eq 'cygwin' && (!exists $ENV{'CYGWIN'} || $ENV{'CYGWIN'} !~ /server/i);
+    skip "Optional modules (IPC::Semaphore, IPC::SysV, MIME::Base64) not installed",5
+     unless eval {
+               require IPC::Semaphore;
+               require IPC::SysV;
+               require MIME::Base64;
+              };
+
     my $session = tie my %session, $package, undef, {
         Store     => 'DB_File',
         Lock      => 'Semaphore',

=== modified file 't/99md5gen.t'
--- t/99md5gen.t	2006-06-22 16:37:15 +0000
+++ t/99md5gen.t	2007-03-21 11:53:52 +0000
@@ -9,15 +9,15 @@
                require Digest::MD5;
               };
 
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
-
 plan tests => 33;
 
 my $package = 'Apache::Session::Generate::MD5';
 use_ok $package;
 
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
+
 my $session = {};
 
 Apache::Session::Generate::MD5::generate($session);
@@ -43,4 +43,4 @@
          "id is $length chars long";
 }
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99moduniqgen.t'
--- t/99moduniqgen.t	2006-06-22 16:37:15 +0000
+++ t/99moduniqgen.t	2007-03-21 11:53:52 +0000
@@ -4,15 +4,15 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
+plan tests => 4;
+
+my $package = 'Apache::Session::Generate::ModUniqueId';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 4;
-
-my $package = 'Apache::Session::Generate::ModUniqueId';
-use_ok $package;
-
 $ENV{UNIQUE_ID} = '12345678790abcdef';
 
 my $session = {};

=== modified file 't/99mysql.t'
--- t/99mysql.t	2006-06-22 16:37:15 +0000
+++ t/99mysql.t	2007-03-21 11:53:52 +0000
@@ -4,23 +4,23 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
+plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
+  unless $ENV{APACHE_SESSION_MAINTAINER};
 plan skip_all => "Optional modules (DBD::mysql, DBI) not installed"
   unless eval {
                require DBI;
                require DBD::mysql;
               };
-plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
-  unless $ENV{APACHE_SESSION_MAINTAINER};
-
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
 
 plan tests => 13;
 
 my $package = 'Apache::Session::MySQL';
 use_ok $package;
 
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
+
 my $session = {};
 
 tie %{$session}, $package, undef, {
@@ -101,4 +101,4 @@
 untie %{$session};
 $dbh->disconnect;
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99mysqllock.t'
--- t/99mysqllock.t	2006-06-22 16:37:15 +0000
+++ t/99mysqllock.t	2007-03-21 11:53:52 +0000
@@ -4,23 +4,23 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
+plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
+  unless $ENV{APACHE_SESSION_MAINTAINER};
 plan skip_all => "Optional modules (DBD::mysql, DBI) not installed"
   unless eval {
                require DBI;
                require DBD::mysql;
               };
-plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
-  unless $ENV{APACHE_SESSION_MAINTAINER};
-
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
 
 plan tests => 4;
 
 my $package = 'Apache::Session::Lock::MySQL';
 use_ok $package;
 
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
+
 my $session = {
     args => {
         LockDataSource => 'dbi:mysql:test',
@@ -66,4 +66,4 @@
 $sth2->finish;
 $dbh->disconnect;
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99mysqlstore.t'
--- t/99mysqlstore.t	2006-06-22 16:37:15 +0000
+++ t/99mysqlstore.t	2007-03-21 11:53:52 +0000
@@ -4,17 +4,17 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
+plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
+  unless $ENV{APACHE_SESSION_MAINTAINER};
 plan skip_all => "Optional modules (DBD::mysql, DBI) not installed"
   unless eval {
                require DBI;
                require DBD::mysql;
               };
-plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
-  unless $ENV{APACHE_SESSION_MAINTAINER};
 
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
 
 plan tests => 2;
 
@@ -25,4 +25,4 @@
 
 isa_ok $foo, $package;
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99nulllock.t'
--- t/99nulllock.t	2006-06-22 16:37:15 +0000
+++ t/99nulllock.t	2007-03-21 11:53:52 +0000
@@ -9,9 +9,9 @@
                require Fcntl;
               };
 
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
 
 plan tests => 4;
 
@@ -29,4 +29,4 @@
 
 undef $lock;
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99oracle.t'
--- t/99oracle.t	2006-06-22 16:37:15 +0000
+++ t/99oracle.t	2007-03-21 11:53:52 +0000
@@ -4,17 +4,17 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
+plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
+  unless $ENV{APACHE_SESSION_MAINTAINER};
 plan skip_all => "Optional modules (DBD::Oracle, DBI) not installed"
   unless eval {
                require DBI;
                require DBD::Oracle;
               };
-plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
-  unless $ENV{APACHE_SESSION_MAINTAINER};
 
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
 
 plan tests => 13;
 
@@ -99,4 +99,4 @@
 $dbh->commit;
 $dbh->disconnect;
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99postgres.t'
--- t/99postgres.t	2006-06-22 16:37:15 +0000
+++ t/99postgres.t	2007-03-21 11:53:52 +0000
@@ -4,13 +4,13 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
+plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
+  unless $ENV{APACHE_SESSION_MAINTAINER};
 plan skip_all => "Optional modules (DBD::Pg, DBI) not installed"
   unless eval {
                require DBI;
                require DBD::Pg;
               };
-plan skip_all => "Not running RDBM tests without APACHE_SESSION_MAINTAINER=1"
-  unless $ENV{APACHE_SESSION_MAINTAINER};
 
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );

=== modified file 't/99semaphore.t'
--- t/99semaphore.t	2006-06-22 16:37:15 +0000
+++ t/99semaphore.t	2007-03-21 11:53:52 +0000
@@ -4,20 +4,25 @@
 use File::Temp qw[tempdir];
 use Cwd qw[getcwd];
 
-plan skip_all => "Optional modules (IPC::SysV, IPC::Semaphore) not installed"
+BEGIN {
+ plan skip_all => "Optional modules (IPC::SysV, IPC::Semaphore) not installed"
   unless eval {
                require IPC::SysV;
                require IPC::Semaphore;
               };
-
-my $origdir = getcwd;
-my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
-chdir( $tempdir );
+ plan skip_all => "Cygserver is not running"
+  if $^O eq 'cygwin' && (!exists $ENV{'CYGWIN'} || $ENV{'CYGWIN'} !~ /server/i);
+}
 
 plan tests => 29;
 
 my $package = 'Apache::Session::Lock::Semaphore';
 use_ok $package;
+
+#my $origdir = getcwd;
+#my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
+#chdir( $tempdir );
+
 use IPC::SysV qw(IPC_CREAT S_IRWXU SEM_UNDO);
 use IPC::Semaphore;
 
@@ -80,4 +85,4 @@
     $sem->remove;
 }
 
-chdir( $origdir );
+#chdir( $origdir );

=== modified file 't/99storable.t'
--- t/99storable.t	2006-06-22 16:37:15 +0000
+++ t/99storable.t	2007-03-21 11:53:52 +0000
@@ -9,15 +9,15 @@
                require Storable;
               };
 
+plan tests => 2;
+
+my $package = 'Apache::Session::Serialize::Storable';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 2;
-
-my $package = 'Apache::Session::Serialize::Storable';
-use_ok $package;
-
 
 my $serial   = \&Apache::Session::Serialize::Storable::serialize;
 my $unserial = \&Apache::Session::Serialize::Storable::unserialize;

=== modified file 't/99uue.t'
--- t/99uue.t	2006-06-22 16:37:15 +0000
+++ t/99uue.t	2007-03-21 11:53:52 +0000
@@ -9,15 +9,15 @@
                require Storable;
               };
 
+plan tests => 2;
+
+my $package = 'Apache::Session::Serialize::UUEncode';
+use_ok $package;
+
 my $origdir = getcwd;
 my $tempdir = tempdir( DIR => '.', CLEANUP => 1 );
 chdir( $tempdir );
 
-plan tests => 2;
-
-my $package = 'Apache::Session::Serialize::UUEncode';
-use_ok $package;
-
 my $serial = \&Apache::Session::Serialize::UUEncode::serialize;
 my $unserial = \&Apache::Session::Serialize::UUEncode::unserialize;
 

